@@ -310,7 +310,7 @@
 //! [`transmute`]:      https://doc.rust-lang.org/std/mem/fn.transmute.html
 
 #![doc(
-    html_root_url = "https://docs.rs/embed_plist/1.2.1",
+    html_root_url = "https://docs.rs/embed_plist/1.2.2",
     html_logo_url = "https://raw.githubusercontent.com/nvzqz/embed-plist-rs/main/img/icon.svg?sanitize=true"
 )]
 #![no_std]
@@ -437,7 +437,7 @@ macro_rules! embed_info_plist_bytes {
             #[link_section = "__TEXT,__info_plist,regular,no_dead_strip"]
             // Prevents repeated use by creating a linker error.
             #[no_mangle]
-            static _EMBED_INFO_PLIST: [u8; LEN] = *REF;
+            pub static _EMBED_INFO_PLIST: [u8; LEN] = *REF;
         };
     };
 }
@@ -567,7 +567,7 @@ macro_rules! embed_launchd_plist_bytes {
             #[link_section = "__TEXT,__launchd_plist,regular,no_dead_strip"]
             // Prevents repeated use by creating a linker error.
             #[no_mangle]
-            static _EMBED_LAUNCHD_PLIST: [u8; LEN] = *REF;
+            pub static _EMBED_LAUNCHD_PLIST: [u8; LEN] = *REF;
         };
     };
 }
